@@ -21,4 +21,9 @@
 # from .responses.api_gateway_proxy import APIGatewayProxyResponseV1, APIGatewayProxyResponseV2
 # from .responses.s3_batch import S3BatchResponse
 
-from .index import SQSEvent, say
+import index
+
+# from .context import Context
+import events
+import responses
+from .index import context, say
